# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['servicecatalogtordf']

package_data = \
{'': ['*']}

install_requires = \
['datacatalogtordf>=1.4.0,<2.0.0', 'skolemizer>=1.0.0,<2.0.0']

setup_kwargs = {
    'name': 'servicecatalogtordf',
    'version': '0.1.0a2',
    'description': 'A library that will map a service catalog (cpsv) to rdf',
    'long_description': '![Tests](https://github.com/Informasjonsforvaltning/servicecatalogtordf/workflows/Tests/badge.svg)\n[![codecov](https://codecov.io/gh/Informasjonsforvaltning/servicecatalogtordf/branch/main/graph/badge.svg)](https://codecov.io/gh/Informasjonsforvaltning/servicecatalogtordf)\n[![PyPI](https://img.shields.io/pypi/v/servicecatalogtordf.svg)](https://pypi.org/project/servicecatalogtordf/)\n[![Read the Docs](https://readthedocs.org/projects/servicecatalogtordf/badge/)](https://servicecatalogtordf.readthedocs.io/)\n# servicecatalogtordf\nA library that will map a service catalog (cpsv) to rdf\n\nThe library contains helper classes for the following dcat classes:\n - [Catalog](https://www.w3.org/TR/vocab-dcat-2/#Class:Catalog)\n - [Service](https://www.w3.org/TR/vocab-dcat-2/#Class:Service)\n\n\n## Usage\n### Install\n```\n% pip install servicecatalogtordf\n```\n### Getting started\n```\nfrom datacatalogtordf import Catalog\nfrom servicecatalogtordf import Service\n\n# Create catalog object\ncatalog = Catalog()\ncatalog.identifier = "http://example.com/catalogs/1"\ncatalog.title = {"en": "A service catalog"}\ncatalog.publisher = "https://example.com/publishers/1"\n\n# Create a service:\nservice = Service()\nservice.identifier = "http://example.com/services/1"\nservice.title = {"nb": "inntektsAPI", "en": "incomeAPI"}\n#\n# Add service to catalog:\ncatalog.services.append(service)\n\n# Get rdf representation in turtle (default)\nrdf = catalog.to_rdf()\nprint(rdf.decode())\n```\n## Development\n### Requirements\n- [pyenv](https://github.com/pyenv/pyenv) (recommended)\n- [pipx](https://github.com/pipxproject/pipx) (recommended)\n- [poetry](https://python-poetry.org/)\n- [nox](https://nox.thea.codes/en/stable/)\n- [nox-poetry](https://github.com/cjolowicz/nox-poetry)\n\n```\n% pipx install poetry==1.1.6\n% pipx install nox==2020.12.31\n% pipx inject nox nox-poetry\n```\n### Install\n```\n% git clone https://github.com/Informasjonsforvaltning/servicecatalogtordf.git\n% cd servicecatalogtordf\n% pyenv install 3.9.4\n% pyenv local 3.9.4\n% poetry install\n```\n### Run all sessions\n```\n% nox\n```\n### Run all tests with coverage reporting\n```\n% nox -rs tests\n```\n### Debugging\nYou can enter into [Pdb](https://docs.python.org/3/library/pdb.html) by passing `--pdb` to pytest:\n```\nnox -rs tests -- --pdb\n```\nYou can set breakpoints directly in code by using the function `breakpoint()`.\n',
    'author': 'Stig B. Dørmænen',
    'author_email': 'stigbd@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Informasjonsforvaltning/servicecatalogtordf',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
